darkhistory.electrons.positronium
=================================

.. automodule:: darkhistory.electrons.positronium

   
   
   .. rubric:: Functions

   .. autosummary::
      :toctree: positronium

      ortho_photon_spec
      para_photon_spec
      weighted_photon_spec
   
   

   
   
   

   
   
   